@@ -26,7 +26,6 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "oxygenbutton.h"
-#include "oxygenbutton.moc"
 #include "oxygenclient.h"
 
 #include <cmath>
@@ -90,6 +89,26 @@ namespace Oxygen
         else return buttonDetailColor( palette, isActive() || _client.isForcedActive() );
     }
 
+    //___________________________________________________
+    QColor Button::buttonDetailColor( const QPalette& palette, bool active ) const
+    {
+        if( _type == ButtonItemClose )
+        {
+
+            return active ?
+                palette.color(QPalette::Active, QPalette::WindowText ):
+                _helper.inactiveTitleBarTextColor( palette );
+
+        } else {
+
+            return active ?
+                palette.color(QPalette::Active, QPalette::ButtonText ):
+                _helper.inactiveButtonTextColor( palette );
+
+        }
+
+    }
+
     //___________________________________________________
     bool Button::isActive( void ) const
     { return (!_forceInactive) && _client.isActive(); }
@@ -131,8 +150,8 @@ namespace Oxygen
 
         // base button color
         QColor base;
-        if( _type == ButtonItemClose && _forceInactive ) base = _client.backgroundPalette( this, palette ).window().color();
-        else if( _type == ButtonItemClose ) base = palette.window().color();
+        if( _type == ButtonItemClose && _forceInactive ) base = _client.backgroundPalette( this, palette ).color( QPalette::Window );
+        else if( _type == ButtonItemClose ) base = palette.color( QPalette::Window );
         else base = palette.button().color();
 
         // text color
@@ -160,8 +179,6 @@ namespace Oxygen
 
         if( hasDecoration() )
         {
-            // scale
-            qreal scale( (21.0*_client.buttonSize())/22.0 );
 
             // pressed state
             const bool pressed(
@@ -171,7 +188,7 @@ namespace Oxygen
                 ( _type == ButtonBelow && _client.keepBelow() ) );
 
             // draw button shape
-            painter.drawPixmap(0, 0, _helper.windecoButton( base, glow, pressed, scale ) );
+            painter.drawPixmap(0, 0, _helper.windecoButton( base, glow, pressed, _client.buttonSize() ) );
 
         }
 
@@ -203,12 +220,12 @@ namespace Oxygen
 
             // contrast
             painter.setBrush(Qt::NoBrush);
+            painter.translate(0, 0.5);
             painter.setPen(QPen( _helper.calcLightColor( base ), width, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
             drawIcon(&painter);
 
             // main
             painter.translate(0,-1.5);
-            painter.setBrush(Qt::NoBrush);
             painter.setPen(QPen(color, width, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
             drawIcon(&painter);
 
@@ -345,7 +362,7 @@ namespace Oxygen
     {
 
         painter->save();
-        painter->setWindow( 0, 0, 22, 22 );
+        painter->setWindow( 0, 0, 21, 21 );
 
         switch(_type)
         {
@@ -379,16 +396,16 @@ namespace Oxygen
                 case Client::MaximizeRestore:
                 case Client::MaximizeVertical:
                 case Client::MaximizeHorizontal:
-                painter->drawLine(QPointF( 7.5,11.5), QPointF(10.5, 8.5));
-                painter->drawLine(QPointF(10.5, 8.5), QPointF(13.5,11.5));
+                painter->drawLine(QPointF( 7.5, 11.5 ), QPointF( 10.5, 8.5) );
+                painter->drawLine(QPointF( 10.5, 8.5 ), QPointF( 13.5, 11.5) );
                 break;
 
                 case Client::MaximizeFull:
                 {
-                    painter->translate(1.5, 1.5);
+                    painter->translate(1.5, 1.0 );
                     QPoint points[4] = {QPoint(9, 6), QPoint(12, 9), QPoint(9, 12), QPoint(6, 9)};
                     painter->drawPolygon(points, 4);
-                    painter->translate(-1.5, -1.5);
+                    painter->translate(-1.5, -1.0 );
                     break;
                 }
             }
